<?php

// autoload_classmap.php @generated by Composer

$vendorDir = dirname(__DIR__);
$baseDir = dirname($vendorDir);

return array(
    'Composer\\InstalledVersions' => $vendorDir . '/composer/InstalledVersions.php',
    'WordPress\\ByteStream\\ByteStreamException' => $baseDir . '/ByteStream/class-bytestreamexception.php',
    'WordPress\\ByteStream\\NotEnoughDataException' => $baseDir . '/ByteStream/class-notenoughdataexception.php',
    'WordPress\\ByteStream\\ReadStream\\BaseByteReadStream' => $baseDir . '/ByteStream/ReadStream/class-basebytereadstream.php',
    'WordPress\\ByteStream\\ReadStream\\ByteReadStream' => $baseDir . '/ByteStream/ReadStream/interface-bytereadstream.php',
    'WordPress\\ByteStream\\ReadStream\\FileReadStream' => $baseDir . '/ByteStream/ReadStream/class-filereadstream.php',
    'WordPress\\DataLiberation\\BlockMarkup\\BlockMarkupProcessor' => $baseDir . '/DataLiberation/BlockMarkup/class-blockmarkupprocessor.php',
    'WordPress\\DataLiberation\\BlockMarkup\\BlockMarkupUrlProcessor' => $baseDir . '/DataLiberation/BlockMarkup/class-blockmarkupurlprocessor.php',
    'WordPress\\DataLiberation\\BlockMarkup\\BlockObject' => $baseDir . '/DataLiberation/BlockMarkup/class-blockobject.php',
    'WordPress\\DataLiberation\\CSS\\CSSProcessor' => $baseDir . '/DataLiberation/CSS/class-cssprocessor.php',
    'WordPress\\DataLiberation\\EntityReader\\EntityReader' => $baseDir . '/DataLiberation/EntityReader/entity-reader.php',
    'WordPress\\DataLiberation\\EntityReader\\WXREntityReader' => $baseDir . '/DataLiberation/EntityReader/class-wxrentityreader.php',
    'WordPress\\DataLiberation\\ImportEntity' => $baseDir . '/DataLiberation/class-importentity.php',
    'WordPress\\DataLiberation\\URL\\CSSURLProcessor' => $baseDir . '/DataLiberation/URL/class-cssurlprocessor.php',
    'WordPress\\DataLiberation\\URL\\ConvertedUrl' => $baseDir . '/DataLiberation/URL/class-convertedurl.php',
    'WordPress\\DataLiberation\\URL\\URLInTextProcessor' => $baseDir . '/DataLiberation/URL/class-urlintextprocessor.php',
    'WordPress\\DataLiberation\\URL\\WPURL' => $baseDir . '/DataLiberation/URL/class-wpurl.php',
    'WordPress\\XML\\XMLAttributeToken' => $baseDir . '/XML/class-xmlattributetoken.php',
    'WordPress\\XML\\XMLDecoder' => $baseDir . '/XML/class-xmldecoder.php',
    'WordPress\\XML\\XMLElement' => $baseDir . '/XML/class-xmlelement.php',
    'WordPress\\XML\\XMLProcessor' => $baseDir . '/XML/class-xmlprocessor.php',
    'WordPress\\XML\\XMLUnsupportedException' => $baseDir . '/XML/class-xmlunsupportedexception.php',
);
