.wp-block-social-links .wp-social-link{
  line-height:0;
}

.wp-block-social-link-anchor{
  align-items:center;
  background:none;
  border:0;
  box-sizing:border-box;
  color:currentColor;
  cursor:pointer;
  display:inline-flex;
  font-family:inherit;
  font-size:inherit;
  font-weight:inherit;
  height:auto;
  margin:0;
  opacity:1;
  padding:.25em;
}
.wp-block-social-link-anchor:hover{
  transform:none;
}

:root :where(.wp-block-social-links.is-style-pill-shape .wp-social-link button){
  padding-left:.6666666667em;
  padding-right:.6666666667em;
}

:root :where(.wp-block-social-links.is-style-logos-only .wp-social-link button){
  padding:0;
}

.wp-block-social-link__toolbar_content_text{
  width:250px;
}