.wp-block[data-align=center] .wp-block-search .wp-block-search__inside-wrapper{
  margin:auto;
}

.wp-block-search :where(.wp-block-search__button){
  align-items:center;
  border-radius:initial;
  display:flex;
  height:auto;
  justify-content:center;
  text-align:center;
}

.wp-block-search__inspector-controls .components-base-control{
  margin-bottom:0;
}