.wp-block-button__link{
  background-color:#32373c;
  border-radius:9999px;
  box-shadow:none;
  color:#fff;
  font-size:1.125em;
  padding:calc(.667em + 2px) calc(1.333em + 2px);
  text-decoration:none;
}

.wp-block-file__button{
  background:#32373c;
  color:#fff;
}

.wp-block-accordion-heading{
  margin:0;
}

.wp-block-accordion-heading__toggle{
  background-color:inherit !important;
  color:inherit !important;
}
.wp-block-accordion-heading__toggle:not(:focus-visible){
  outline:none;
}
.wp-block-accordion-heading__toggle:focus,.wp-block-accordion-heading__toggle:hover{
  background-color:inherit !important;
  border:none;
  box-shadow:none;
  color:inherit;
  padding:var(--wp--preset--spacing--20, 1em) 0;
  text-decoration:none;
}
.wp-block-accordion-heading__toggle:focus-visible{
  outline:auto;
  outline-offset:0;
}