.wp-block-social-links div.block-editor-url-input{
  display:inline-block;
  margin-right:8px;
}

.wp-social-link:hover{
  transform:none;
}

:root :where(.wp-block-social-links){
  padding:0;
}

.wp-block.wp-block-social-links.aligncenter,.wp-block[data-align=center]>.wp-block-social-links{
  justify-content:center;
}

.block-editor-block-preview__content .components-button:disabled{
  opacity:1;
}

.wp-social-link.wp-social-link__is-incomplete{
  opacity:.5;
}

.wp-block-social-links .is-selected .wp-social-link__is-incomplete,.wp-social-link.wp-social-link__is-incomplete:focus,.wp-social-link.wp-social-link__is-incomplete:hover{
  opacity:1;
}

.wp-block-social-links .block-list-appender{
  position:static;
}
.wp-block-social-links .block-list-appender .block-editor-inserter{
  font-size:inherit;
}
.wp-block-social-links .block-list-appender .block-editor-button-block-appender{
  font-size:inherit;
  height:1.5em;
  padding:0;
  width:1.5em;
}