<?php

declare( strict_types=1 );

namespace Rowbot\URL\State;

class StatusCode {
	public const OK = 'ok';
	public const CONTINUE = 'continue';
	public const BREAK = 'break';
	public const FAILURE = 'failure';
}
