.wp-block-navigation .wp-block-navigation-item__label{
  overflow-wrap:break-word;
}
.wp-block-navigation .wp-block-navigation-item__description{
  display:none;
}

.link-ui-tools{
  outline:1px solid #f0f0f0;
  padding:8px;
}

.link-ui-block-inserter{
  padding-top:8px;
}

.link-ui-block-inserter__back{
  margin-left:8px;
  text-transform:uppercase;
}