.preference-base-option+.preference-base-option{
  margin-top:16px;
}
@media (min-width:600px){
  .preferences-modal{
    height:calc(100% - 128px);
    width:calc(100% - 32px);
  }
}
@media (min-width:782px){
  .preferences-modal{
    width:750px;
  }
}
@media (min-width:960px){
  .preferences-modal{
    height:70%;
  }
}
@media (max-width:781px){
  .preferences-modal .components-modal__content{
    padding:0;
  }
}

.preferences__tabs-tablist{
  left:16px;
  position:absolute !important;
  top:88px;
  width:160px;
}

.preferences__tabs-tabpanel{
  margin-left:160px;
  padding-left:24px;
}

@media (max-width:781px){
  .preferences__provider{
    height:100%;
  }
}
.preferences-modal__section{
  border:0;
  margin:0 0 2.5rem;
  padding:0;
}
.preferences-modal__section:last-child{
  margin:0;
}

.preferences-modal__section-legend{
  margin-bottom:8px;
}

.preferences-modal__section-title{
  font-size:.9rem;
  font-weight:600;
  margin-top:0;
}

.preferences-modal__section-description{
  color:#757575;
  font-size:12px;
  font-style:normal;
  margin:-8px 0 8px;
}

.preferences-modal__section:has(.preferences-modal__section-content:empty){
  display:none;
}